@@ -22,6 +22,10 @@
 #---------------------------------------------------------------------------
 from modules.base_module import RanaModule
 
+DEVICE_DESKTOP = 1
+DEVICE_SMARTPHONE = 2
+DEVICE_TABLET = 3
+
 class DeviceModule(RanaModule):
   """A modRana device module"""
   
@@ -234,7 +238,32 @@ class DeviceModule(RanaModule):
     # TODO: respect the modRana internet connectivity state
     pass
 
+  def getStartDragDistance(self):
+    """Distance in pixel for discerning drag from a click
+    A correct start drag distance is important on high DPI screens
+    as the default values don't work correctly on them.
+    """
+    return None
 
+  def getDeviceType(self):
+    """Returns type of the current device
+
+    The device can currently be either a PC
+    (desktop or laptop/notebook),
+    smartphone or a tablet.
+    This is currently used mainly for rough
+    DPI estimation.
+    Example:
+    * high resolution & PC -> low DPI
+    * high resolution & smartphone -> high DPI
+    * high resolution & smartphone -> low DPI
+
+    This could also be used in the future to
+    use different PC/smartphone/tablet GUI styles.
+
+    By default, the device type is unknown.
+    """
+    return None
 
 #  def getAutorotationSupported(self):
 #    return False
