@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_device_module import DeviceModule
+from base_device_module import DeviceModule, DEVICE_SMARTPHONE
 
 
 # NOTE: use the device_ prefix when naming the module
@@ -120,3 +120,6 @@ class DeviceN9(DeviceModule):
   def needsQuitButton(self):
     """No need for a separate Quit button thanks to Swipe UI"""
     return False
+
+  def getDeviceType(self):
+    return DEVICE_SMARTPHONE
