@@ -21,7 +21,7 @@
 #---------------------------------------------------------------------------
 import subprocess
 import time
-from base_device_module import DeviceModule
+from base_device_module import DeviceModule, DEVICE_SMARTPHONE
 #N900 specific:
 import dbus.glib
 
@@ -615,3 +615,6 @@ class DeviceN900(DeviceModule):
   def enableInternetConnectivity(self):
     """autoconnect to the Internet using DBUS"""
     subprocess.call(["sh", "modules/device_modules/n900_maemo5_autoconnect_dbus.sh"])
+
+  def getDeviceType(self):
+    return DEVICE_SMARTPHONE
