@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
-from base_device_module import DeviceModule
+from base_device_module import DeviceModule, DEVICE_DESKTOP
 
 def getModule(m,d,i):
   return DeviceNetbook(m,d,i)
@@ -43,4 +43,7 @@ class DeviceNetbook(DeviceModule):
     return False
 
   def getSupportedGUIModuleIds(self):
-    return ["GTK", "QML"]
\ No newline at end of file
+    return ["GTK", "QML"]
+
+  def getDeviceType(self):
+    return DEVICE_DESKTOP
\ No newline at end of file
