@@ -20,7 +20,7 @@ from __future__ import with_statement # for python 2.5
 import threading
 from time import sleep, time
 
-from base_position_source import PositionSource
+from .base_position_source import PositionSource
 from core.fix import Fix
 
 
@@ -40,7 +40,9 @@ class GPSD(PositionSource):
       self.GPSDConsumer.start()
       self.connected = True
       self.setGPSDDebug(self.debug) # check if verbose debugging is enabled
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("location GPSD: connecting to GPSD failed", e)
       self.status = "No GPSD running"
 
@@ -55,11 +57,9 @@ class GPSD(PositionSource):
     if self.connected:
       fix, sats = self.GPSDConsumer.getBoth()
       if fix:
-        """
-        as the GPSD consumer updates its values very often, it probably better to use a simple
-        tuple instead of a Fix object and only convert to the Fix object once the position data
-        is actually requested
-        """
+        # as the GPSD consumer updates its values very often, it probably better to use a simple
+        # tuple instead of a Fix object and only convert to the Fix object once the position data
+        # is actually requested
         #        (lat,lon,elevation,bearing,speed,timestamp) = fix
         satCount = len(sats)
         inUseSatCount = len(filter(lambda x: x.used, sats))
@@ -193,7 +193,9 @@ class GPSDConsumer(threading.Thread):
         break
       try:
         self.session.next() # this function blocks until a new fix is available
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("GPSD: error: GPS daemon not running")
         print(e)
       sf = self.session.fix
@@ -208,7 +210,9 @@ class GPSDConsumer(threading.Thread):
               print('GPSD fix debug')
               print(
               'mode:' + str(sf.mode) + ' lat,lon:' + str((sf.latitude, sf.longitude)) + ' elev:' + str(sf.altitude))
-            except  Exception, e:
+            except Exception:
+              import sys
+              e = sys.exc_info()[1]
               print('ERROR debugging GPSD fix')
               print(e)
       else:
@@ -221,7 +225,7 @@ class GPSDConsumer(threading.Thread):
   #        with self.lock:
   #          try:
   #            self.fix = (r['lat'],r['lon'],r['alt'],r['track'],r['speed'], time())
-  #          except Exception, e:
+  #          except Exception:            import sys            e = sys.exc_info()[1]
   #            print("GPSDConsumer: error reading data", e)
 
   def shutdown(self):
