@@ -68,12 +68,18 @@ class MapData(RanaModule):
     self.notificateOnce = True
     self.scroll = 0
     self.onlineRequestTimeout = 30
-    """ how often should be the download info
-    updated during batch, in seconds"""
+    # how often should the download info be
+    # updated during batch download, in seconds
     self.batchInfoUpdateInterval = 0.5
     self.mapFolderPath = None
     self._mapLayersModule = None
 
+    self.x = None
+    self.y = None
+    self.z = None
+    self.tiles = []
+    self.totalSize = 0
+
   def firstTime(self):
     # cache the map folder path
     self.mapFolderPath = self.modrana.paths.getMapFolderPath()
@@ -715,7 +721,6 @@ class MapData(RanaModule):
 
         # try to retrieve and store the tile
         failed = False
-        dl = False
         try:
           dlSize = self.saveTileForURL(item)
         except Exception:
@@ -741,9 +746,19 @@ class MapData(RanaModule):
       (url, filename, folder, folderPrefix, layerType) = self.callback.getTileUrlAndPath(x, y, z, self.layer)
       m = self.callback.m.get('storeTiles', None) # get the tile storage module
       if m:
-        # does the the file exist ?
+        goAhead = False
+        redownload = int(self.callback.get('batchRedownloadAvailableTiles', False))
+        if not redownload:
+          # does the the file exist ?
+          # -> don't download it if it does
+          goAhead = not m.tileExists(filename, folderPrefix, z, x, y, layerType, fromThread=True)
+        elif redownload == 1: # redownload all
+          goAhead = True
+        elif redownload == 2: # update
+          # only download tiles in the area that already exist
+          goAhead = m.tileExists(filename, folderPrefix, z, x, y, layerType, fromThread=True)
         # TODO: maybe make something like tile objects so we don't have to pass so many parameters ?
-        if not m.tileExists(filename, folderPrefix, z, x, y, layerType, fromThread=True): # if the file does not exist
+        if goAhead : # if the file does not exist
           request = self.connPool.request('get', url)
           size = int(request.getheaders()['content-length'])
           content = request.data
