@@ -18,20 +18,27 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
 from __future__ import with_statement # for python 2.5
-import StringIO
 from modules.base_module import RanaModule
 from threading import Thread
 import threading
 import os
-import traceback
-import urllib2
 import time
 import string
-from core import utils
-from modules import urllib3
-from core import rectangles
+import sys
+import traceback
 
+try:  # Python 2
+  from urllib2 import urlopen, HTTPError, URLError
+except ImportError:  # Python 3
+  from urllib.request import urlopen
+  from urllib.error import HTTPError, URLError
+
+from modules import urllib3
+from core import utils
+from core import rectangles
 from core.tilenames import *
+from core.backports import six
+StringIO = six.moves.cStringIO
 
 #import socket
 #timeout = 30 # this sets timeout for all sockets
@@ -56,7 +63,8 @@ if gs.GUIString == "GTK":
     import Image
     import ImageOps
     IMAGE_MANIPULATION_IMPORT_SUCCESS = True
-  except ImportError, e:
+  except ImportError:
+    e = sys.exc_info()[1]
     print('mapTiles: import of image manipulation tools unsuccessful'
           ' - tile image manipulation disabled')
     print(e)
@@ -146,6 +154,26 @@ class MapTiles(RanaModule):
     #      print("got tile FROM memory CACHE")
       return cacheItem[0]
 
+    # get the layer object
+    layer = self._getLayerById(layerId)
+    if layer is None:
+      print("mapTiles: invalid layer")
+      return None
+    if layer is None: # is the layer info valid ?
+      print("mapTiles: error: layer with id: %s not found" % layerId)
+      return None
+    layerPrefix = layer.folderName
+    layerType = layer.type
+    tileData = self._storeTiles.getTileData(layerPrefix, z, x, y, layerType)
+    if tileData:
+      #print("got tile FROM disk CACHE")
+      # tile was available from storage
+      return tileData
+    else: # download
+      #print("download")
+      return self.downloadTile(layerId, z, x, y)
+
+  def downloadTile(self, layerId, z, x, y):
     # get the layer object
     layer = self._getLayerById(layerId)
     if layer is None:
@@ -156,19 +184,13 @@ class MapTiles(RanaModule):
       return
     layerPrefix = layer.folderName
     layerType = layer.type
-    tileData = self._storeTiles.getTileData(layerPrefix, z, x, y, layerType)
-    if tileData:
-    #      print("got tile FROM disk CACHE")
-      # tile was available from storage
-      return tileData
-
-    #    print("download")
     tileUrl = self.getTileUrl(x, y, z, layerId)
-    #    print(url)
-    response = self._getConnPool(layerId, tileUrl).get_url(tileUrl)
-    #    print("RESPONSE")
+    # print("GET TILE")
+    # print(tileUrl)
+    response = self._getConnPool(layerId, tileUrl).request('GET', tileUrl)
+    # print("RESPONSE")
+    # print(response)
     tileData = response.data
-
     if tileData:
       # check if the data is actually an image, and not an error page
       if utils.isTheStringAnImage(tileData):
@@ -335,7 +357,8 @@ class MapTiles(RanaModule):
                   name = request[0]
                   self.removeImageFromMemory(name)
               self.downloadRequestPool = cleanPool
-        except Exception, e:
+        except Exception:
+          e = sys.exc_info()[1]
           print("exception in tile download manager thread:\n%s" % e)
           #          traceback.print_exc()
 
@@ -363,7 +386,8 @@ class MapTiles(RanaModule):
       #        print("quiting")
         self.idleLoaderActive = False
         return False # the stack is empty, remove this callback
-    except Exception, e:
+    except Exception:
+      e = sys.exc_info()[1]
       # on an error, we need to shut down or else idleLoaderActive might get stuck
       # and no loader will be started
       print("mapTiles: exception in idle loader\n", e)
@@ -669,7 +693,8 @@ class MapTiles(RanaModule):
         #      process all the "load" notifications """
         #      pass
 
-    except Exception, e:
+    except Exception:
+      e = sys.exc_info()[1]
       print("mapTiles: exception while drawing the map layer: %s" % e)
       traceback.print_exc()
 
@@ -833,7 +858,8 @@ class MapTiles(RanaModule):
     try:
       pixbuf = gtk.gdk.pixbuf_new_from_file(filePath)
       return pixbuf
-    except Exception, e:
+    except Exception:
+      e = sys.exc_info()[1]
       print("the tile image is corrupted nad/or there are no tiles for this zoomlevel, exception:\n%s" % e)
       return False
 
@@ -980,7 +1006,7 @@ class MapTiles(RanaModule):
       return Image.fromstring("RGB",(256,256),pb.get_pixels() )
 
     def image2pixbuf(im):
-      file1 = StringIO.StringIO()
+      file1 = StringIO()
       im.save(file1, "ppm")
       contents = file1.getvalue()
       file1.close()
@@ -1093,13 +1119,13 @@ class MapTiles(RanaModule):
   class TileDownloader(Thread):
     """Downloads an image (in a thread)"""
 
-    def __init__(self, name, x, y, z, layer, layerName, layerType, filename, callback):
+    def __init__(self, name, x, y, z, layerId, layerName, layerType, filename, callback):
       Thread.__init__(self)
       self.name = name
       self.x = x
       self.y = y
       self.z = z
-      self.layer = layer
+      self.layerId = layerId
       self.layerName = layerName
       self.layerType = layerType
       self.finished = 0
@@ -1114,11 +1140,11 @@ class MapTiles(RanaModule):
           self.x,
           self.y,
           self.z,
-          self.layer,
+          self.layerId,
           self.filename)
         self.finished = 1
       # something is wrong with the server or url
-      except urllib2.HTTPError:
+      except urllib3.exceptions.HTTPError:
         if self.useImageSurface:
           tileDownloadFailedSurface = self.callback.images[1]['tileDownloadFailed'][0]
           expireTimestamp = time.time() + 10
@@ -1130,7 +1156,7 @@ class MapTiles(RanaModule):
           #  - the error tile is shown without modifying the pipeline too much
           #  - modRana will eventually try to download the tile again,
           #    after it is flushed with old tiles from the memory
-      except urllib2.URLError:
+      except URLError:
         if self.useImageSurface:
           tileNetworkErrorSurface = self.callback.images[1]['tileNetworkError'][0]
           expireTimestamp = time.time() + 10
@@ -1141,7 +1167,8 @@ class MapTiles(RanaModule):
           # TODO: actually remove tiles according to expiration timestamp :)
 
       # something other is wrong (most probably a corrupted tile)
-      except Exception, e:
+      except Exception:
+        e = sys.exc_info()[1]
         self.printErrorMessage(e)
         # remove the status tile
         self.callback.removeImageFromMemory(self.name)
@@ -1159,26 +1186,25 @@ class MapTiles(RanaModule):
           self.callback.threadListCondition.notifyAll()
 
     def printErrorMessage(self, e):
-      url = self.callback.getTileUrl(self.x, self.y, self.z, self.layer)
+      url = self.callback.getTileUrl(self.x, self.y, self.z, self.layerId)
       print("mapTiles: download thread reports error")
       print("** we were doing this, when an exception occurred:")
       print("** downloading tile: x:%d,y:%d,z:%d, layer:%s, filename:%s, url: %s" % (
         self.x,
         self.y,
         self.z,
-        self.layer,
+        self.layerId,
         self.filename,
         url))
       print("** this exception occurred: %s\n" % e)
       print("** traceback:\n")
       traceback.print_exc()
 
-    def downloadTile(self, name, x, y, z, layer, filename):
+    def downloadTile(self, name, x, y, z, layerId, filename):
       """Downloads an image"""
-      url = self.callback.getTileUrl(x, y, z, layer)
-      request = urllib2.urlopen(url)
-      content = request.read()
-      request.close()
+      content = self.callback.downloadTile(layerId, z, x, y)
+      if content is None:
+        raise urllib3.exceptions.HTTPError
       if self.useImageSurface:
         pl = gtk.gdk.PixbufLoader()
 
