@@ -20,7 +20,7 @@
 from modules.base_module import RanaModule
 import time
 import math
-from core import geo
+from core import geo, constants
 from core import utils
 
 # only import GKT libs if GTK GUI is used
@@ -48,6 +48,7 @@ class Menus(RanaModule):
     self.hideMapScreenButtons = False
     self.lastHideCheckTimestamp = time.time()
     self.itemMenuGrid = (None,[])
+    self.icons = None
 
     # tools menu
     self.itemToolsMenuCache = (None, None)
@@ -650,7 +651,7 @@ class Menus(RanaModule):
         persist[uniqueName] = index
         self.set('persistentToggleButtons', persist)
 
-    """we are counting up from zero for the item indexes"""
+    # we are counting up from zero for the item indexes
     self.menus[menu][itemCount] = (textIconAction, index, uniqueName, menuType)
     self.menus[menu]['metadata']['itemCount'] = itemCount + 1
 
@@ -1029,7 +1030,24 @@ class Menus(RanaModule):
     self.addItem('editBatch', 'Zoom down#now: %d + %d = %d' % (z,zoomDown,maxZ), 'generic', 'set:menu:zoomDown')
     self.addItem('editBatch', 'Zoom up#now: %d - %d = %d' % (z,zoomUp,minZ), 'generic', 'set:menu:zoomUp')
 
-    # on exit from submenu, we need to refresh the editBacht menu, so we also send setupEditBatchMenu
+    # redownload toggle button
+    baseAction = '|tracklog:setNewLoggingInterval'
+    textIconAction = [
+      ('OFF#redownload', '', 'set:batchRedownloadAvailableTiles:False'+baseAction),
+      (constants.PANGO_ON + '#redownload', '', 'set:batchRedownloadAvailableTiles:True'+baseAction),
+      ('update#redownload', '', 'set:batchRedownloadAvailableTiles:2'+baseAction)
+    ]
+    # batchRedownloadAvailableTiles meanings:
+    # False/0 -> download only tiles that aren't locally available
+    # True/1 -> download all tiles
+    # 2 -> download only tiles that are locally available (update all tiles in area)
+
+    index = self.get('batchRedownloadAvailableTiles', False)
+    # True -> second state will be used (ON)
+    # False -> first state will be used (OFF)
+    self.addToggleItem('editBatch', textIconAction, index, None, 'batchRedownloadAvailableTiles')
+
+    # on exit from submenu, we need to refresh the editBatch menu, so we also send setupEditBatchMenu
     self.setupDataMenu('editBatch|menu:setupEditBatchMenu', 'editBatch')
     self.setupDataSubMenu('editBatch|menu:setupEditBatchMenu', 'editBatch')
     self.setupZoomDownMenu('editBatch|menu:setupEditBatchMenu', 'editBatch')
