@@ -35,7 +35,7 @@ class Options(RanaModule):
   def __init__(self, m, d, i):
     RanaModule.__init__(self, m, d, i)
     self.options = {}
-    """for fast searching defaults for corresponding keys"""
+    # for fast searching defaults for corresponding keys
     self.keyDefault = {}
 
     # profile folder
@@ -43,11 +43,6 @@ class Options(RanaModule):
     # check the profile path and create the folders if necessary
     utils.createFolderPath(self.profileFolderPath)
 
-    # load persistent options
-    #    self.load()
-    self.on = '<span color="green">ON</span>'
-    self.off = '<span color="red">OFF</span>'
-
     # items menu cache
     self.itemMenus = {}
 
@@ -120,8 +115,8 @@ class Options(RanaModule):
 
 
   def addBoolOption(self, title, variable, group, default=None, action=None):
-    on = self.on
-    off = self.off
+    on = constants.PANGO_ON
+    off = constants.PANGO_OFF
 
     if action:
       states = ((False, off, action), (True, on, action))
@@ -516,7 +511,7 @@ class Options(RanaModule):
        (15000, "long drag", changedMsg),
        (40000, "really long drag", changedMsg),
        (80000, "extremely long drag", changedMsg),
-       (False, self.off, changedMsg)],
+       (False, constants.PANGO_OFF, changedMsg)],
       group,
       2048)
 
@@ -748,8 +743,8 @@ class Options(RanaModule):
     group = addGroup("Turn by turn", "turn_by_turn", catNavigation, "generic")
 
     addOpt("Autostart navigation", "autostartNavigationDefaultOnAutoselectTurn",
-      [('disabled', "OFF"),
-       ('enabled', "ON")],
+      [('disabled', constants.PANGO_OFF),
+       ('enabled', constants.PANGO_ON)],
       group,
       'enabled')
 
@@ -1393,7 +1388,7 @@ class Options(RanaModule):
 
           # draw mode specific combined toggle & indicator
           if self.modrana.hasKeyModifierInMode(variable, mode):
-            toggleText = '<span color="green">ON</span>#per Mode'
+            toggleText = constants.PANGO_ON + '#per Mode'
             modeSpecToggleAction = "ml:options:removeKeyModifier:%s;%s" % (variable, mode)
           else:
             toggleText = "OFF#per Mode"
